==> pipewire-docs-1%3A0.3.30-2-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/context_8c.js <==
var context_8c =
[
    [ "object_entry", "structobject__entry.html", "structobject__entry" ],
    [ "CLOCK_MAX_QUANTUM", "context_8c.html#adc981923431e3d5cd4c7dbbfd5684887", null ],
    [ "CLOCK_MIN_QUANTUM", "context_8c.html#aaa7e2937ee16b43739d5bc830d9ad1fb", null ],
    [ "DEFAULT_CLOCK_MAX_QUANTUM", "context_8c.html#a0079001bae95c9c9b2624aa2bfd37d1b", null ],
    [ "DEFAULT_CLOCK_MIN_QUANTUM", "context_8c.html#a04d3c7ec92b4a78d9a77fe2790be9e9a", null ],
    [ "DEFAULT_CLOCK_POWER_OF_TWO_QUANTUM", "context_8c.html#a320dd4d70f273497536a27da6cbbc195", null ],
    [ "DEFAULT_CLOCK_QUANTUM", "context_8c.html#a92a629b69a1b0f877fc0ee658a2953ac", null ],
    [ "DEFAULT_CLOCK_RATE", "context_8c.html#a97e89412f3549291a46f26b87ce44fa3", null ],
    [ "DEFAULT_LINK_MAX_BUFFERS", "context_8c.html#af8fb6f642966400172a5c0d253a669b5", null ],
    [ "DEFAULT_MEM_ALLOW_MLOCK", "context_8c.html#a66a2ddaf05dcf9696aa9d494191ea6c1", null ],
    [ "DEFAULT_MEM_WARN_MLOCK", "context_8c.html#a899f8b5950491d2538eadbdf4fff905b", null ],
    [ "DEFAULT_VIDEO_HEIGHT", "context_8c.html#a39f078c4b4708b93f1ba4d9d2753d07f", null ],
    [ "DEFAULT_VIDEO_RATE_DENOM", "context_8c.html#a21a24c4dc8767aa4bb139f52120c12eb", null ],
    [ "DEFAULT_VIDEO_RATE_NUM", "context_8c.html#a1556603b94e169527fdb5318fbf077d3", null ],
    [ "DEFAULT_VIDEO_WIDTH", "context_8c.html#aa21ee0c65b1e9925619ea51375bed99c", null ],
    [ "NAME", "context_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "pw_context_add_listener", "group__pw__context.html#ga44d2d1b5d618438873016c764584f1e5", null ],
    [ "pw_context_add_spa_lib", "group__pw__context.html#gace5ee0a357a22a1dd86e3398956a621e", null ],
    [ "pw_context_destroy", "group__pw__context.html#ga41fdab6368603144f0911541182713a1", null ],
    [ "pw_context_find_export_type", "group__pw__context.html#ga8864661d392f052418a0c8fc00929cbb", null ],
    [ "pw_context_find_format", "context_8c.html#a68cdc41b6bc8400932d7f77ff0a601eb", null ],
    [ "pw_context_find_global", "group__pw__context.html#ga4b42764d2a50b3c1b3273246b84d1c75", null ],
    [ "pw_context_find_port", "context_8c.html#a7c9448c018c0d3fb7737bd0d7b23e58f", null ],
    [ "pw_context_find_spa_lib", "group__pw__context.html#gab8cedcc93cbde35f3cb9225b969cef43", null ],
    [ "pw_context_for_each_global", "group__pw__context.html#gaaa07217fcfeba4dd0a0269ff313a75d7", null ],
    [ "pw_context_get_conf_section", "group__pw__context.html#ga5da58001a9cefc969bd4f55f69ae32b3", null ],
    [ "pw_context_get_main_loop", "group__pw__context.html#gae9b6023dfaa0defcf16a2ebafa901840", null ],
    [ "pw_context_get_object", "group__pw__context.html#ga24cd5c5f4aeabae5850b5b1a85cfbcb9", null ],
    [ "pw_context_get_properties", "group__pw__context.html#gaa2be0c032178ed27936b716ffa8ea4c5", null ],
    [ "pw_context_get_support", "group__pw__context.html#ga4adfd99a7941665d15f4ad368cf68ab1", null ],
    [ "pw_context_get_user_data", "group__pw__context.html#gaa09ebbaed5dbf26b9a304d49beecdf94", null ],
    [ "pw_context_get_work_queue", "group__pw__context.html#gafef9fcc0ef91738137aaa32783fdfe94", null ],
    [ "pw_context_load_spa_handle", "group__pw__context.html#ga9fa7b0905bf18003532e4740050caf09", null ],
    [ "pw_context_new", "group__pw__context.html#ga560a7075bb5665ae349c85ae876e7103", null ],
    [ "pw_context_recalc_graph", "context_8c.html#af6af5924b93ff1fa11bc8732096319dc", null ],
    [ "pw_context_register_export_type", "group__pw__context.html#ga39a9e29ddc0cad4ced7d6034a64e3aff", null ],
    [ "pw_context_set_object", "group__pw__context.html#ga1e67973ea8236ff8bc6125a437b79a76", null ],
    [ "pw_context_update_properties", "group__pw__context.html#ga48011f6ba07333a33f880778da4a1c86", null ],
    [ "SPA_PRINTF_FUNC", "context_8c.html#a90ef780aa33ff63c3bd9cf0f417c711a", null ]
];

==> pipewire-docs-1%3A0.3.34-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/context_8c.js <==
var context_8c =
[
    [ "object_entry", "structobject__entry.html", "structobject__entry" ],
    [ "DEFAULT_CLOCK_MAX_QUANTUM", "context_8c.html#a0079001bae95c9c9b2624aa2bfd37d1b", null ],
    [ "DEFAULT_CLOCK_MIN_QUANTUM", "context_8c.html#a04d3c7ec92b4a78d9a77fe2790be9e9a", null ],
    [ "DEFAULT_CLOCK_POWER_OF_TWO_QUANTUM", "context_8c.html#a320dd4d70f273497536a27da6cbbc195", null ],
    [ "DEFAULT_CLOCK_QUANTUM", "context_8c.html#a92a629b69a1b0f877fc0ee658a2953ac", null ],
    [ "DEFAULT_CLOCK_RATE", "context_8c.html#a97e89412f3549291a46f26b87ce44fa3", null ],
    [ "DEFAULT_LINK_MAX_BUFFERS", "context_8c.html#af8fb6f642966400172a5c0d253a669b5", null ],
    [ "DEFAULT_MEM_ALLOW_MLOCK", "context_8c.html#a66a2ddaf05dcf9696aa9d494191ea6c1", null ],
    [ "DEFAULT_MEM_WARN_MLOCK", "context_8c.html#a899f8b5950491d2538eadbdf4fff905b", null ],
    [ "DEFAULT_VIDEO_HEIGHT", "context_8c.html#a39f078c4b4708b93f1ba4d9d2753d07f", null ],
    [ "DEFAULT_VIDEO_RATE_DENOM", "context_8c.html#a21a24c4dc8767aa4bb139f52120c12eb", null ],
    [ "DEFAULT_VIDEO_RATE_NUM", "context_8c.html#a1556603b94e169527fdb5318fbf077d3", null ],
    [ "DEFAULT_VIDEO_WIDTH", "context_8c.html#aa21ee0c65b1e9925619ea51375bed99c", null ],
    [ "NAME", "context_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "pw_context_add_listener", "group__pw__context.html#ga44d2d1b5d618438873016c764584f1e5", null ],
    [ "pw_context_add_spa_lib", "group__pw__context.html#gace5ee0a357a22a1dd86e3398956a621e", null ],
    [ "pw_context_debug_port_params", "context_8c.html#a48516aac937b8d35fb63f4e62a78d253", null ],
    [ "pw_context_destroy", "group__pw__context.html#ga41fdab6368603144f0911541182713a1", null ],
    [ "pw_context_find_export_type", "group__pw__context.html#ga8864661d392f052418a0c8fc00929cbb", null ],
    [ "pw_context_find_format", "context_8c.html#a68cdc41b6bc8400932d7f77ff0a601eb", null ],
    [ "pw_context_find_global", "group__pw__context.html#ga4b42764d2a50b3c1b3273246b84d1c75", null ],
    [ "pw_context_find_port", "context_8c.html#a7c9448c018c0d3fb7737bd0d7b23e58f", null ],
    [ "pw_context_find_spa_lib", "group__pw__context.html#gab8cedcc93cbde35f3cb9225b969cef43", null ],
    [ "pw_context_for_each_global", "group__pw__context.html#gaaa07217fcfeba4dd0a0269ff313a75d7", null ],
    [ "pw_context_get_conf_section", "group__pw__context.html#ga5da58001a9cefc969bd4f55f69ae32b3", null ],
    [ "pw_context_get_main_loop", "group__pw__context.html#gae9b6023dfaa0defcf16a2ebafa901840", null ],
    [ "pw_context_get_object", "group__pw__context.html#ga24cd5c5f4aeabae5850b5b1a85cfbcb9", null ],
    [ "pw_context_get_properties", "group__pw__context.html#gaa2be0c032178ed27936b716ffa8ea4c5", null ],
    [ "pw_context_get_support", "group__pw__context.html#ga4adfd99a7941665d15f4ad368cf68ab1", null ],
    [ "pw_context_get_user_data", "group__pw__context.html#gaa09ebbaed5dbf26b9a304d49beecdf94", null ],
    [ "pw_context_get_work_queue", "group__pw__context.html#gafef9fcc0ef91738137aaa32783fdfe94", null ],
    [ "pw_context_load_spa_handle", "group__pw__context.html#ga9fa7b0905bf18003532e4740050caf09", null ],
    [ "pw_context_new", "group__pw__context.html#ga560a7075bb5665ae349c85ae876e7103", null ],
    [ "pw_context_recalc_graph", "context_8c.html#af6af5924b93ff1fa11bc8732096319dc", null ],
    [ "pw_context_register_export_type", "group__pw__context.html#ga39a9e29ddc0cad4ced7d6034a64e3aff", null ],
    [ "pw_context_set_object", "group__pw__context.html#ga1e67973ea8236ff8bc6125a437b79a76", null ],
    [ "pw_context_update_properties", "group__pw__context.html#ga48011f6ba07333a33f880778da4a1c86", null ]
];
